@@ -43,7 +43,7 @@ cor.fk <- function (x, y = NULL)
 	if (length (x) != length (y))
 		stop ("x and y must have same length.")
 
-	ret <- .C ("kendallNlogN", PACKAGE = "pcaPP", NAOK = FALSE, DUP = FALSE
+	ret <- .C ("kendallNlogN", PACKAGE = "pcaPP", NAOK = FALSE, DUP = TRUE		##	20130322 set DUP = TRUE - kendallNlogN implementation modifies x & y vectors!!
 				, as.double (x)
 				, as.double (y)
 				, as.integer (c (length (x), cor))
